"""
🐚  About
---------

c is a Python project providing a metapath hook for loading C extension
modules without prior compilation by a 'setup.py' script. It uses the
:py:mod:`sysconfig` module to extract the necessary information for compiling
an extension module.

Loadable modules are identified by the '.py.c', '.py.m', and '.py.c++' suffix.
Composition of multiple files is not directly supported, but preprocessor
directives may be used in order to combine multiple files.

Sample
------

Typical usage::

	>>> import package.libfoo
	>>> package.libfoo.return_true()
	True

Where::

	package/
		__init__.py
		libfoo.py.c

libfoo.py.c::

	/*
	 * libfoo.py.c - test library for the c loader
	 */
	#include <Python.h>
	#include <structmember.h>

	static PyObject *
	return_true(PyObject *self)
	{
		Py_INCREF(Py_True);
		return(Py_True);
	}

	/* METH_O, METH_VARARGS, METH_VARKEYWORDS, METH_NOARGS */
	static PyMethodDef methods[] = {
		{"return_true", (PyCFunction) return_true, METH_NOARGS, "return `True`"},
		{NULL}
	};

	static struct PyModuleDef module = {
		PyModuleDef_HEAD_INIT,
		"package.libfoo",	/* name of module */
		NULL,					/* module documentation, may be NULL */
		-1,					/* size of per-interpreter state of the module,
									or -1 if the module keeps state in global variables. */
		methods,
	};

	PyMODINIT_FUNC
	PyInit_libfoo(void)
	{
		PyObject *mod;
		mod = PyModule_Create(&module);
		return(mod);
	}
"""
__pkg_bottom__ = True
