"""
Compilation and linkage basics.
"""
import sys

def compile(target, filename, type):
	"""
	Construct the parameters to be used to compile and link the new executable.
	"""
	import sysconfig # avoid module overhead unless it's needed.
	if sys.platform == 'darwin' and type == 'objc':
		# assume macosx
		plat = ('-framework', 'Foundation')
	else:
		plat = ()

	cc = sysconfig.get_config_var('CC')
	if 'clang' in cc:
		shhh = ('-Warray-bounds',) # It's a good warning, but PyTuple_SET_ITEM()...
	else:
		shhh = ()

	plat = ()

	includes = ('-I', sysconfig.get_config_var('INCLUDEPY'))
	return (cc, '-v', '-g',) + shhh + includes + plat + ('-o', target, '-c', filename)

def link(target, filename, type):
	"""
	Construct the parameters to be used to compile and link the new executable.
	"""
	import sysconfig # avoid module overhead unless it's needed.
	if sys.platform == 'darwin' and type == 'objc':
		# assume macosx
		plat = ('-framework', 'Foundation')
	else:
		plat = ()

	link = tuple(sysconfig.get_config_var('BLDSHARED').split())
	libs = tuple((sysconfig.get_config_var('SHLIBS') or '').split())
	syslibs = tuple((sysconfig.get_config_var('SYSLIBS') or '').split())
	ldflags = tuple((sysconfig.get_config_var('LDFLAGS') or '').split())
	pyversion = sysconfig.get_config_var('VERSION') or ''.join(map(str, sys.version_info[:2]))
	pyspec = 'python' + pyversion + sys.abiflags

	return link + libs + syslibs + ldflags + plat + (
		'-v',
		'-L' + sysconfig.get_config_var('LIBDIR'),
		'-l' + pyspec,
		'-o', target, filename,
	)
