##
# .release.xdistutils - distutils data
##
"""
Python distutils data module.

This module exists in the case that someone wants to sub-package a distribution
as opposed to relying on install-time dependency resolution.

For sub-packagers, the `prefixed_packages` and `prefixed_extensions` functions
should be of particular interest.
"""
import sys
import os
import distutils.core
import distutils.command.install
from .. import project, loader
from . import pypi

subpackages = [
	'bin',
	'test',
	'documentation',
	'release',
]

package_data = {
	'documentation' : ['*.rst'],
	'documentation.sphinx' : ['*.py', '*.sh'],
	'test' : ['*.c', '*.m'],
	None : ['*.c',],
}

if __package__ is not None:
	default_prefix = __package__.split('.')[:-1]
else:
	default_prefix = __name__.split('.')[:-2]

def prefixed_packages(
	prefix = default_prefix,
	packages = subpackages,
):
	"""
	Generator producing the standard `package` list prefixed with `prefix`.
	"""
	prefix = '.'.join(prefix)
	yield prefix
	prefix = prefix + '.'
	for pkg in packages:
		yield prefix + pkg

def prefixed_package_data(
	prefix = default_prefix,
	package_data = package_data,
):
	"""
	Generator producing the standard `package` list prefixed with `prefix`.
	"""
	prefix = '.'.join(prefix)
	for pkg, data in package_data.items():
		if pkg is None:
			yield prefix, data
		else:
			yield prefix + '.' + pkg, data

class LocalInstall(distutils.command.install.install):
	def run(self, pth_install = loader.autoload):
		r = super().run()
		pth_install()
		return r

def standard_setup_keywords(build_extensions = True, prefix = default_prefix):
	return {
		'name' : project.name,
		'version' : project.version,
		'description' : project.description,
		'author' : project.meaculpa,
		'author_email' : project.contact,
		'url' : pypi.URL,
		'long_description' : pypi.LONG_DESCRIPTION,
		'classifiers' : pypi.CLASSIFIERS,
		'packages' : list(prefixed_packages(prefix = prefix)),
		'package_data' : dict(prefixed_package_data(prefix = prefix)),
		'cmdclass': dict(install = LocalInstall),
	}
